@@ -31,11 +31,12 @@ class MCPInstallCommands:
 
         # Step 1: Install MCP package if needed
         print("\n1️⃣  Checking MCP package installation...")
-        try:
-            import mcp
+        import importlib.util
 
+        mcp_spec = importlib.util.find_spec("mcp")
+        if mcp_spec:
             print("✅ MCP package already installed")
-        except ImportError:
+        else:
             print("📦 Installing MCP package...")
             try:
                 subprocess.check_call([sys.executable, "-m", "pip", "install", "mcp"])
@@ -46,19 +47,50 @@ class MCPInstallCommands:
                 return 1
 
         # Step 2: Configure Claude Code with the new CLI command
-        print("\n2️⃣  Configuring Claude Code (~/.claude.json)...")
+        print("\n2️⃣  Configuring Claude Code...")
         try:
             success = self._configure_claude_desktop(args.force)
-            if success:
-                print("✅ Configuration completed successfully")
-                print("\n🎉 MCP Gateway is ready to use!")
-                print("\nNext steps:")
-                print("1. Restart Claude Code (if running)")
-                print("2. Test the server: claude-mpm mcp server --test")
-                print("3. Check status: claude-mpm mcp status")
-                return 0
-            print("❌ Configuration failed")
-            return 1
+            if not success:
+                print("❌ Main gateway configuration failed")
+                return 1
+
+            # Step 3: Setup external MCP services
+            print("\n3️⃣  Setting up External MCP Services...")
+            from .mcp_setup_external import MCPExternalServicesSetup
+
+            external_setup = MCPExternalServicesSetup(self.logger)
+
+            # Check if user wants to set up external services
+            response = (
+                input(
+                    "\nDo you want to set up external MCP services (mcp-vector-search, mcp-browser)? (Y/n): "
+                )
+                .strip()
+                .lower()
+            )
+            if response in ["", "y", "yes"]:
+                # Install Python packages for external services
+                external_setup.check_and_install_pip_packages()
+
+                # Setup external services in Claude Code config
+                if external_setup.setup_external_services(force=args.force):
+                    print("✅ External services configured successfully")
+                else:
+                    print("⚠️ Some external services may not have been configured")
+            else:
+                print("⏭️ Skipping external services setup")
+                print(
+                    "   You can set them up later with: claude-mpm mcp external setup"
+                )
+
+            print("\n✅ Configuration completed successfully")
+            print("\n🎉 MCP Gateway is ready to use!")
+            print("\nNext steps:")
+            print("1. Restart Claude Code (if running)")
+            print("2. Test the server: claude-mpm mcp server --test")
+            print("3. Check status: claude-mpm mcp status")
+            print("4. List external services: claude-mpm mcp external list")
+            return 0
 
         except Exception as e:
             print(f"❌ Error during configuration: {e}")
@@ -67,9 +99,9 @@ class MCPInstallCommands:
     def _configure_claude_desktop(self, force=False):
         """Configure Claude Code to use the MCP gateway via CLI command.
 
-        WHY: Claude Code reads MCP server configurations from ~/.claude.json
-        (not ~/.claude/settings.local.json). This method updates that file
-        to include the claude-mpm-gateway server configuration.
+        WHY: Claude Code reads MCP server configurations from a platform-specific
+        configuration file. This method updates that file to include the claude-mpm-gateway
+        server configuration.
 
         Args:
             force: Whether to overwrite existing configuration
@@ -139,11 +171,49 @@ class MCPInstallCommands:
         Returns:
             Path or None: Path to Claude Code config file
         """
+        import platform
 
-        # Claude Code reads MCP server configurations from ~/.claude.json
-        # This is the actual file that Claude Code uses for MCP servers
-        # NOT ~/.claude/settings.local.json
-        return Path.home() / ".claude.json"
+        # Try multiple possible locations for Claude Code config
+        possible_paths = [
+            Path.home()
+            / "Library"
+            / "Application Support"
+            / "Claude"
+            / "claude_desktop_config.json",  # macOS
+            Path.home() / ".config" / "Claude" / "claude_desktop_config.json",  # Linux
+            Path.home()
+            / "AppData"
+            / "Roaming"
+            / "Claude"
+            / "claude_desktop_config.json",  # Windows
+            Path.home() / ".claude" / "claude_desktop_config.json",  # Alternative
+            Path.home() / ".claude.json",  # Legacy
+        ]
+
+        for path in possible_paths:
+            if path.exists():
+                return path
+
+        # If none exist, return the platform-appropriate default
+        system = platform.system()
+        if system == "Darwin":  # macOS
+            return (
+                Path.home()
+                / "Library"
+                / "Application Support"
+                / "Claude"
+                / "claude_desktop_config.json"
+            )
+        if system == "Windows":
+            return (
+                Path.home()
+                / "AppData"
+                / "Roaming"
+                / "Claude"
+                / "claude_desktop_config.json"
+            )
+        # Linux and others
+        return Path.home() / ".config" / "Claude" / "claude_desktop_config.json"
 
     def _find_claude_mpm_executable(self):
         """Find the claude-mpm executable path.
@@ -172,13 +242,12 @@ class MCPInstallCommands:
             return str(executable_path)
 
         # Fallback: Use Python module invocation if no executable found
-        try:
-            import claude_mpm
+        import importlib.util
 
+        claude_mpm_spec = importlib.util.find_spec("claude_mpm")
+        if claude_mpm_spec:
             print(f"   Using Python module: {sys.executable} -m claude_mpm")
             return sys.executable
-        except ImportError:
-            pass
 
         return None
 
@@ -193,7 +262,7 @@ class MCPInstallCommands:
             dict or None: Configuration dictionary
         """
         import json
-        from datetime import datetime
+        from datetime import datetime, timezone
 
         config = {}
 
@@ -226,7 +295,7 @@ class MCPInstallCommands:
 
                     # Create backup
                     backup_path = config_path.with_suffix(
-                        f'.backup.{datetime.now().strftime("%Y%m%d_%H%M%S")}.json'
+                        f'.backup.{datetime.now(timezone.utc).strftime("%Y%m%d_%H%M%S")}.json'
                     )
                     try:
                         config_path.rename(backup_path)
@@ -240,7 +309,7 @@ class MCPInstallCommands:
                         existing_config = json.load(f)
                     config = existing_config
                     print("   Force mode: Overwriting existing configuration")
-                except:
+                except Exception:
                     pass  # File doesn't exist or is invalid, start fresh
 
         # Ensure mcpServers section exists
