@@ -1,32 +1,35 @@
 """Core components for Claude MPM."""
 
 from .claude_runner import ClaudeRunner
-from .mixins import LoggerMixin
 from .config import Config
 
 # Import DI components
 from .container import DIContainer, ServiceLifetime, get_container
-from .service_registry import ServiceRegistry, get_service_registry, initialize_services
-from .injectable_service import InjectableService
 from .factories import (
-    ServiceFactory, AgentServiceFactory, SessionManagerFactory, 
-    ConfigurationFactory, get_factory_registry
+    AgentServiceFactory,
+    ConfigurationFactory,
+    ServiceFactory,
+    SessionManagerFactory,
+    get_factory_registry,
 )
+from .injectable_service import InjectableService
+from .mixins import LoggerMixin
+from .service_registry import ServiceRegistry, get_service_registry, initialize_services
 
 __all__ = [
+    "AgentServiceFactory",
     "ClaudeRunner",
-    "LoggerMixin",
     "Config",
+    "ConfigurationFactory",
     "DIContainer",
+    "InjectableService",
+    "LoggerMixin",
+    "ServiceFactory",
     "ServiceLifetime",
-    "get_container",
     "ServiceRegistry",
+    "SessionManagerFactory",
+    "get_container",
+    "get_factory_registry",
     "get_service_registry",
     "initialize_services",
-    "InjectableService",
-    "ServiceFactory",
-    "AgentServiceFactory",
-    "SessionManagerFactory",
-    "ConfigurationFactory",
-    "get_factory_registry",
-]
\ No newline at end of file
+]
