@@ -8,22 +8,28 @@ and default values with proper validation and type conversion.
 import json
 import logging
 import os
+import threading
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 import yaml
 
+from claude_mpm.core.logging_utils import get_logger
+
 from ..utils.config_manager import ConfigurationManager
 from .exceptions import ConfigurationError, FileOperationError
 from .unified_paths import get_path_manager
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class Config:
     """
     Configuration manager for Claude PM services.
 
+    Implements singleton pattern to ensure configuration is loaded only once
+    and shared across all services.
+
     Supports loading from:
     - Python dictionaries
     - JSON files
@@ -31,6 +37,34 @@ class Config:
     - Environment variables
     """
 
+    _instance = None
+    _initialized = False
+    _success_logged = (
+        False  # Class-level flag to track if success message was already logged
+    )
+    _lock = threading.Lock()  # Thread safety for singleton initialization
+
+    def __new__(cls, *args, **kwargs):
+        """Implement singleton pattern to ensure single configuration instance.
+
+        WHY: Configuration was being loaded 11 times during startup, once for each service.
+        This singleton pattern ensures configuration is loaded only once and reused.
+        Thread-safe implementation prevents race conditions during concurrent initialization.
+        """
+        if cls._instance is None:
+            with cls._lock:
+                # Double-check locking pattern for thread safety
+                if cls._instance is None:
+                    cls._instance = super().__new__(cls)
+                    logger.info("Creating new Config singleton instance")
+                else:
+                    logger.debug(
+                        "Reusing existing Config singleton instance (concurrent init)"
+                    )
+        else:
+            logger.debug("Reusing existing Config singleton instance")
+        return cls._instance
+
     def __init__(
         self,
         config: Optional[Dict[str, Any]] = None,
@@ -45,49 +79,93 @@ class Config:
             config_file: Path to configuration file (JSON or YAML)
             env_prefix: Prefix for environment variables
         """
-        self._config: Dict[str, Any] = {}
-        self._env_prefix = env_prefix
-        self._config_mgr = ConfigurationManager(cache_enabled=True)
+        # Skip initialization if already done (singleton pattern)
+        # Use thread-safe check to prevent concurrent initialization
+        if Config._initialized:
+            logger.debug("Config already initialized, skipping re-initialization")
+            # If someone tries to load a different config file after initialization,
+            # log a debug message but don't reload
+            if config_file and str(config_file) != getattr(self, "_loaded_from", None):
+                logger.debug(
+                    f"Ignoring config_file parameter '{config_file}' - "
+                    f"configuration already loaded from '{getattr(self, '_loaded_from', 'defaults')}'"
+                )
+            return
 
-        # Load base configuration
-        if config:
-            self._config.update(config)
+        # Thread-safe initialization - acquire lock for ENTIRE initialization process
+        with Config._lock:
+            # Double-check pattern - check again inside the lock
+            if Config._initialized:
+                logger.debug(
+                    "Config already initialized (concurrent), skipping re-initialization"
+                )
+                return
 
-        # Track where configuration was loaded from
-        self._loaded_from = None
+            Config._initialized = True
+            logger.info("Initializing Config singleton for the first time")
 
-        # Load from file if provided
-        if config_file:
-            self.load_file(config_file)
-            self._loaded_from = str(config_file)
-        else:
-            # Try to load from standard location: .claude-mpm/configuration.yaml
-            default_config = Path.cwd() / ".claude-mpm" / "configuration.yaml"
-            if default_config.exists():
-                self.load_file(default_config)
-                self._loaded_from = str(default_config)
+            # Initialize instance variables inside the lock to ensure thread safety
+            self._config: Dict[str, Any] = {}
+            self._env_prefix = env_prefix
+            self._config_mgr = ConfigurationManager(cache_enabled=True)
+
+            # Load base configuration
+            if config:
+                self._config.update(config)
+
+            # Track where configuration was loaded from
+            self._loaded_from = None
+            # Track the actual file we loaded from to prevent re-loading
+            self._actual_loaded_file = None
+
+            # Load from file if provided
+            # Note: Only ONE config file should be loaded, and success message shown only once
+            if config_file:
+                self.load_file(config_file, is_initial_load=True)
+                self._loaded_from = str(config_file)
             else:
-                # Also try .yml extension
-                alt_config = Path.cwd() / ".claude-mpm" / "configuration.yml"
-                if alt_config.exists():
-                    self.load_file(alt_config)
+                # Try to load from standard location: .claude-mpm/configuration.yaml
+                default_config = Path.cwd() / ".claude-mpm" / "configuration.yaml"
+                if default_config.exists():
+                    self.load_file(default_config, is_initial_load=True)
+                    self._loaded_from = str(default_config)
+                elif (
+                    alt_config := Path.cwd() / ".claude-mpm" / "configuration.yml"
+                ).exists():
+                    # Also try .yml extension (using walrus operator for cleaner code)
+                    self.load_file(alt_config, is_initial_load=True)
                     self._loaded_from = str(alt_config)
 
-        # Load from environment variables (new and legacy prefixes)
-        self._load_env_vars()
-        self._load_legacy_env_vars()
+            # Load from environment variables (new and legacy prefixes)
+            self._load_env_vars()
+            self._load_legacy_env_vars()
 
-        # Apply defaults
-        self._apply_defaults()
+            # Apply defaults
+            self._apply_defaults()
 
-    def load_file(self, file_path: Union[str, Path]) -> None:
+    def load_file(
+        self, file_path: Union[str, Path], is_initial_load: bool = True
+    ) -> None:
         """Load configuration from file with enhanced error handling.
 
         WHY: Configuration loading failures can cause silent issues. We need
         to provide clear, actionable error messages to help users fix problems.
+
+        Args:
+            file_path: Path to the configuration file
+            is_initial_load: Whether this is the initial configuration load (for logging control)
         """
         file_path = Path(file_path)
 
+        # Check if we've already loaded from this exact file to prevent duplicate messages
+        if hasattr(self, "_actual_loaded_file") and self._actual_loaded_file == str(
+            file_path
+        ):
+            logger.debug(
+                f"Configuration already loaded from {file_path}, skipping reload"
+            )
+            return
+
         if not file_path.exists():
             logger.warning(f"Configuration file not found: {file_path}")
             logger.info(
@@ -113,7 +191,27 @@ class Config:
             file_config = self._config_mgr.load_auto(file_path)
             if file_config:
                 self._config = self._config_mgr.merge_configs(self._config, file_config)
-                logger.info(f"✓ Successfully loaded configuration from {file_path}")
+                # Track that we've successfully loaded from this file
+                self._actual_loaded_file = str(file_path)
+
+                # Only log success message once using class-level flag to avoid duplicate messages
+                # Check if we should log success message (thread-safe for reads after initialization)
+                if is_initial_load:
+                    if not Config._success_logged:
+                        # Set flag IMMEDIATELY before logging to prevent any possibility of duplicate
+                        # messages. No lock needed here since we're already inside __init__ lock
+                        Config._success_logged = True
+                        logger.info(
+                            f"✓ Successfully loaded configuration from {file_path}"
+                        )
+                    else:
+                        # Configuration already successfully loaded before, just debug log
+                        logger.debug(
+                            f"Configuration already loaded, skipping success message for {file_path}"
+                        )
+                else:
+                    # Not initial load (shouldn't happen in normal flow, but handle gracefully)
+                    logger.debug(f"Configuration reloaded from {file_path}")
 
                 # Log important configuration values for debugging
                 if logger.isEnabledFor(logging.DEBUG):
@@ -147,7 +245,7 @@ class Config:
             logger.info("TIP: Validate your JSON at https://jsonlint.com/")
             self._config["_load_error"] = str(e)
 
-        except (OSError, IOError, PermissionError) as e:
+        except (OSError, PermissionError) as e:
             raise FileOperationError(
                 f"Failed to read configuration file: {e}",
                 context={
@@ -207,15 +305,14 @@ class Config:
         # Boolean conversion
         if value.lower() in ("true", "yes", "1", "on"):
             return True
-        elif value.lower() in ("false", "no", "0", "off"):
+        if value.lower() in ("false", "no", "0", "off"):
             return False
 
         # Numeric conversion
         try:
             if "." in value:
                 return float(value)
-            else:
-                return int(value)
+            return int(value)
         except ValueError:
             pass
 
@@ -432,11 +529,54 @@ class Config:
                     },
                 },
             },
+            # Monitor server configuration (decoupled from dashboard)
+            "monitor_server": {
+                "host": "localhost",
+                "port": 8765,  # Default monitor port (shared with dashboard)
+                "enable_health_monitoring": True,
+                "auto_start": False,  # Don't auto-start with dashboard by default
+                "event_buffer_size": 2000,  # Larger buffer for monitor server
+                "client_timeout": 60,  # Timeout for inactive clients
+            },
+            # Dashboard server configuration (connects to monitor)
+            "dashboard_server": {
+                "host": "localhost",
+                "port": 8765,  # Dashboard UI port
+                "monitor_host": "localhost",  # Monitor server host to connect to
+                "monitor_port": 8765,  # Monitor server port to connect to
+                "auto_connect_monitor": True,  # Automatically connect to monitor
+                "monitor_reconnect": True,  # Auto-reconnect to monitor if disconnected
+                "fallback_standalone": True,  # Run in standalone mode if monitor unavailable
+            },
             # Agent deployment configuration
             "agent_deployment": {
                 "excluded_agents": [],  # List of agent IDs to exclude from deployment
                 "exclude_dependencies": False,  # Whether to exclude agent dependencies too
                 "case_sensitive": False,  # Whether agent name matching is case-sensitive
+                "filter_non_mpm_agents": True,  # Filter out non-MPM agents by default
+                "mpm_author_patterns": [
+                    "claude mpm",
+                    "claude-mpm",
+                    "anthropic",
+                ],  # Patterns for MPM agents
+            },
+            # Instruction reinforcement system configuration
+            "instruction_reinforcement": {
+                "enabled": True,
+                "test_mode": True,
+                "injection_interval": 5,
+                "test_messages": [
+                    "[TEST-REMINDER] This is an injected instruction reminder",
+                    "[PM-INSTRUCTION] Remember to delegate all work to agents",
+                    "[PM-INSTRUCTION] Do not use Edit, Write, or Bash tools directly",
+                    "[PM-INSTRUCTION] Your role is orchestration and coordination",
+                ],
+                "production_messages": [
+                    "[PM-REMINDER] Delegate implementation tasks to specialized agents",
+                    "[PM-REMINDER] Use Task tool for all work delegation",
+                    "[PM-REMINDER] Focus on orchestration, not implementation",
+                    "[PM-REMINDER] Your role is coordination and management",
+                ],
             },
         }
 
@@ -502,7 +642,7 @@ class Config:
 
             logger.info(f"Configuration saved to {file_path}")
 
-        except (OSError, IOError, PermissionError) as e:
+        except (OSError, PermissionError) as e:
             raise FileOperationError(
                 f"Failed to write configuration file: {e}",
                 context={
@@ -731,7 +871,7 @@ class Config:
             if "enabled" in memory_config and not isinstance(
                 memory_config["enabled"], bool
             ):
-                errors.append(f"memory.enabled must be boolean")
+                errors.append("memory.enabled must be boolean")
 
             # Check limits
             limits = memory_config.get("limits", {})
@@ -772,7 +912,7 @@ class Config:
         """
         is_valid, errors, warnings = self.validate_configuration()
 
-        status = {
+        return {
             "valid": is_valid,
             "errors": errors,
             "warnings": warnings,
@@ -784,8 +924,18 @@ class Config:
             "memory_enabled": self.get("memory.enabled", False),
         }
 
-        return status
-
     def __repr__(self) -> str:
         """String representation of configuration."""
         return f"<Config({len(self._config)} keys)>"
+
+    @classmethod
+    def reset_singleton(cls):
+        """Reset the singleton instance (mainly for testing purposes).
+
+        WHY: During testing, we may need to reset the singleton to test different
+        configurations. This method allows controlled reset of the singleton state.
+        """
+        cls._instance = None
+        cls._initialized = False
+        cls._success_logged = False
+        logger.debug("Config singleton reset")
