@@ -11,9 +11,8 @@ Configuration via .claude-mpm/configuration.yaml.
 """
 
 import json
-import logging
 import os
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any, Dict, Optional
 
 # Import configuration manager
@@ -31,7 +30,9 @@ try:
 except ImportError:
     ASYNC_AVAILABLE = False
 
-logger = logging.getLogger(__name__)
+from claude_mpm.core.logging_utils import get_logger
+
+logger = get_logger(__name__)
 
 
 class ClaudeSessionLogger:
@@ -133,7 +134,7 @@ class ClaudeSessionLogger:
         # Generate a default based on timestamp if nothing found
         if not session_id:
             # Use a timestamp-based session ID as fallback
-            session_id = datetime.now().strftime("%Y%m%d_%H%M%S")
+            session_id = datetime.now(timezone.utc).strftime("%Y%m%d_%H%M%S")
             logger.info(f"No Claude session ID found, using generated: {session_id}")
         else:
             logger.info(f"Using Claude session ID: {session_id}")
@@ -156,11 +157,10 @@ class ClaudeSessionLogger:
         agent_name = agent_name.replace(" ", "_").lower()
 
         # Generate timestamp with microseconds for uniqueness
-        timestamp = datetime.now().strftime("%Y%m%d_%H%M%S_%f")
+        timestamp = datetime.now(timezone.utc).strftime("%Y%m%d_%H%M%S_%f")
 
         # Create filename: session_id-agent-timestamp.json
-        filename = f"{self.session_id}-{agent_name}-{timestamp}.json"
-        return filename
+        return f"{self.session_id}-{agent_name}-{timestamp}.json"
 
     def log_response(
         self,
@@ -217,7 +217,7 @@ class ClaudeSessionLogger:
 
         # Prepare response data with standardized field names
         response_data = {
-            "timestamp": datetime.now().isoformat(),
+            "timestamp": datetime.now(timezone.utc).isoformat(),
             "session_id": self.session_id,
             "request": request_summary,  # Standardized field name
             "response": response_content,  # Already correct
