@@ -6,24 +6,29 @@ and aggregate results for reporting.
 """
 
 import asyncio
-import logging
 from concurrent.futures import ThreadPoolExecutor, as_completed
 from typing import List, Type
 
+from claude_mpm.core.logging_utils import get_logger
+
 from .checks import (
     AgentCheck,
     BaseDiagnosticCheck,
-    ClaudeDesktopCheck,
+    ClaudeCodeCheck,
     CommonIssuesCheck,
     ConfigurationCheck,
     FilesystemCheck,
     InstallationCheck,
+    InstructionsCheck,
     MCPCheck,
+    MCPServicesCheck,
     MonitorCheck,
     StartupLogCheck,
 )
 from .models import DiagnosticResult, DiagnosticStatus, DiagnosticSummary
 
+logger = get_logger(__name__)
+
 
 class DiagnosticRunner:
     """Orchestrate diagnostic checks and aggregate results.
@@ -41,16 +46,17 @@ class DiagnosticRunner:
         """
         self.verbose = verbose
         self.fix = fix
-        self.logger = logging.getLogger(__name__)
-
+        self.logger = logger  # Add logger initialization
         # Define check order (dependencies first)
         self.check_classes: List[Type[BaseDiagnosticCheck]] = [
             InstallationCheck,
             ConfigurationCheck,
             FilesystemCheck,
-            ClaudeDesktopCheck,
+            InstructionsCheck,  # Check instruction files early
+            ClaudeCodeCheck,
             AgentCheck,
             MCPCheck,
+            MCPServicesCheck,  # Check external MCP services
             MonitorCheck,
             StartupLogCheck,  # Check startup logs for recent issues
             CommonIssuesCheck,
@@ -107,9 +113,21 @@ class DiagnosticRunner:
 
         # Group checks by dependency level
         # Level 1: No dependencies
-        level1 = [InstallationCheck, FilesystemCheck, ConfigurationCheck]
+        level1 = [
+            InstallationCheck,
+            FilesystemCheck,
+            ConfigurationCheck,
+            InstructionsCheck,
+        ]
         # Level 2: May depend on level 1
-        level2 = [ClaudeDesktopCheck, AgentCheck, MCPCheck, MonitorCheck]
+        level2 = [
+            ClaudeCodeCheck,
+            AgentCheck,
+            MCPCheck,
+            MCPServicesCheck,
+            MonitorCheck,
+            StartupLogCheck,
+        ]
         # Level 3: Depends on others
         level3 = [CommonIssuesCheck]
 
@@ -191,8 +209,8 @@ class DiagnosticRunner:
             "config": ConfigurationCheck,
             "filesystem": FilesystemCheck,
             "fs": FilesystemCheck,
-            "claude": ClaudeDesktopCheck,
-            "claude_desktop": ClaudeDesktopCheck,
+            "claude": ClaudeCodeCheck,
+            "claude_code": ClaudeCodeCheck,
             "agents": AgentCheck,
             "agent": AgentCheck,
             "mcp": MCPCheck,
