@@ -7,13 +7,15 @@ WHY this integration module:
 - Provides clean separation of concerns
 """
 
-import logging
+from datetime import datetime, timezone
 from typing import Optional
 
-from claude_mpm.services.event_bus import EventBus, SocketIORelay
+from claude_mpm.core.logging_utils import get_logger
+from claude_mpm.services.event_bus import EventBus
 from claude_mpm.services.event_bus.config import get_config
+from claude_mpm.services.event_bus.direct_relay import DirectSocketIORelay
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class EventBusIntegration:
@@ -33,7 +35,7 @@ class EventBusIntegration:
             server_instance: Optional Socket.IO server instance
         """
         self.server = server_instance
-        self.relay: Optional[SocketIORelay] = None
+        self.relay: Optional[DirectSocketIORelay] = None
         self.event_bus: Optional[EventBus] = None
         self.config = get_config()
         self.enabled = self.config.enabled and self.config.relay_enabled
@@ -47,17 +49,16 @@ class EventBusIntegration:
         Returns:
             bool: True if setup successful
         """
-        from datetime import datetime
 
         print(
-            f"[{datetime.now().isoformat()}] EventBusIntegration.setup() called",
+            f"[{datetime.now(timezone.utc).isoformat()}] EventBusIntegration.setup() called",
             flush=True,
         )
 
         if not self.enabled:
             logger.info("EventBus integration disabled by configuration")
             print(
-                f"[{datetime.now().isoformat()}] EventBus integration disabled by configuration",
+                f"[{datetime.now(timezone.utc).isoformat()}] EventBus integration disabled by configuration",
                 flush=True,
             )
             return False
@@ -65,34 +66,50 @@ class EventBusIntegration:
         try:
             # Get EventBus instance
             print(
-                f"[{datetime.now().isoformat()}] Getting EventBus instance...",
+                f"[{datetime.now(timezone.utc).isoformat()}] Getting EventBus instance...",
                 flush=True,
             )
             self.event_bus = EventBus.get_instance()
             print(
-                f"[{datetime.now().isoformat()}] EventBus instance obtained", flush=True
+                f"[{datetime.now(timezone.utc).isoformat()}] EventBus instance obtained",
+                flush=True,
             )
 
             # Apply configuration
             self.config.apply_to_eventbus(self.event_bus)
 
-            # Create and configure relay
-            relay_port = port or self.config.relay_port
+            # Create direct relay that uses server's broadcaster
             print(
-                f"[{datetime.now().isoformat()}] Creating SocketIORelay on port {relay_port}...",
+                f"[{datetime.now(timezone.utc).isoformat()}] Creating DirectSocketIORelay...",
                 flush=True,
             )
-            self.relay = SocketIORelay(relay_port)
-            self.config.apply_to_relay(self.relay)
+            if self.server:
+                self.relay = DirectSocketIORelay(self.server)
+                print(
+                    f"[{datetime.now(timezone.utc).isoformat()}] DirectSocketIORelay created with server instance",
+                    flush=True,
+                )
+            else:
+                logger.warning("No server instance provided, relay won't work")
+                print(
+                    f"[{datetime.now(timezone.utc).isoformat()}] WARNING: No server instance for relay",
+                    flush=True,
+                )
+                return False
 
             # Start the relay
-            print(f"[{datetime.now().isoformat()}] Starting relay...", flush=True)
-            self.relay.start()
-            print(f"[{datetime.now().isoformat()}] Relay started", flush=True)
-
-            logger.info(f"EventBus integration setup complete (port: {relay_port})")
             print(
-                f"[{datetime.now().isoformat()}] EventBus integration setup complete",
+                f"[{datetime.now(timezone.utc).isoformat()}] Starting relay...",
+                flush=True,
+            )
+            self.relay.start()
+            print(
+                f"[{datetime.now(timezone.utc).isoformat()}] Relay started", flush=True
+            )
+
+            logger.info("EventBus integration setup complete with DirectSocketIORelay")
+            print(
+                f"[{datetime.now(timezone.utc).isoformat()}] EventBus integration setup complete with DirectSocketIORelay",
                 flush=True,
             )
             return True
@@ -100,7 +117,7 @@ class EventBusIntegration:
         except Exception as e:
             logger.error(f"Failed to setup EventBus integration: {e}")
             print(
-                f"[{datetime.now().isoformat()}] Failed to setup EventBus integration: {e}",
+                f"[{datetime.now(timezone.utc).isoformat()}] Failed to setup EventBus integration: {e}",
                 flush=True,
             )
             import traceback
